/*  
    --------------------------------------------------------------------------
	Code for link-hover text boxes
	Original: Mike McGrath (Web Site: http://website.lineone.net/~mike_mcgrath) 
	modified by Nicolas Hoening (Web Site: http://nicolashoening.de)
    Works only if the BrowserDetect script has run before (http://dithered.chadlindstrom.ca/javascript/browser_detect)
    Requires a pop-up object, 'pup', in your basic CSS file.
	--------------------------------------------------------------------------
	Further modified 2010 by Philip Bolt, (www.redhall.org.uk), to allow two types of display, controlled
	by seven procedure parameters in a Function called 'get_popup()', 
	
	'msg';		the message for the popup,
	'lne'; 		a Boolean which selects for a single line display if TRUE, or the original multi-line 
				display if FALSE, (or missing!).
				NB even though 'msg' may contain html tags, offsetWidth  ignores these.
	'wd';		The desired width of the box, (only used if 'lne' is False)
	'fnt';		a string specifying the required 'Font-family, or "", 
	'fsze';		the font size, or zero and
	'fcol';		the font colour, if omitted the default font colour of your 'pup' is used.
				The colour can be defined as a colour name, (e.g. red), an rgb colour,
				(e.g. rgb(27,132,89)), or a hex value, (e.g.#60332d), (12/12/10).
	'bckgrnd'	the background colour, if omitted the default colour of your 'pup' is used.
				The colours can be defined as shown for font colours above, (13/12/10).
				
	Trailing unused parameters can be omitted, but other blank parms. must be defined by 
	a pair of empty quotes, ('' or "").
	
	You have to define all the defaults for 'pup' otherwise, any changes made for one pop-up 
	will be applied to all future ones.
	
	The text length process requires a hidden <span>, ID 'ruler', at the foot of your html.
	e.g. <span id="ruler" ></span>. This needs to have its basic definition in your CSS file.
	e.g.	ruler { 
			visibility: hidden;
			white-space: nowrap; 
			}
	Last update:	23/8/10, 20/10/10, 12/12/10, 13/12/10
*/

var len;	//The length of the string in pixels.
var wid;	//The desired width of the box.
var d_ff="Arial, sans-serif"	//The default Font Family
var d_fs="0.95em"				//The default font size
var d_fc="#545454";				//The default font colour.
var d_bg="#fff5e6";				//The default background colour.

var iex = browser.isIE || browser.isOpera; // opera has a similar engine to IE
var nav = (document.layers);
var old = browser.isNS && (!document.layers && !document.getElementById);
var n_6 = browser.isNS6up;
var op = browser.isOpera; // this is only opera
if (browser.isSafari || browser.isFirefox || browser.isMozilla || browser.isKonqueror || browser.isGecko) n_6 = true; //they work the same for this

// create the popup box - inline so everyone, including Opera, will tell the width
document.write('<div id="pup" style="visibility:hidden;display:inline;"></div>');

var skin = null;		// this is the style of our popup we'll modify

var minMarginToBorder = 15;	//15 set how much minimal space there should be to
							// the next border (horizontally)
var popwidth = 0;   // this is how wide your popup is, we'll read it
					// from the stylesheet later, so keep this as-is
var pw_fact=1;		//The pop width divisor to take account of BR/CR in text, (n = no. of line breaks + 1).
// initialize the capture pointer
if(nav) document.captureEvents(Event.MOUSEMOVE);
if(n_6) document.addEventListener("mousemove", get_mouse, true);
if(nav || iex) document.onmousemove = get_mouse;

//Parameters:	msg;		the text for display, (possibly including html tags),
//				lne;		Boolean flag, TRUE = single line display, FALSE= fixed width display,
//				wd;			Fixed width box in pixels, (0 or missing = 'pup' default),
//				fnt;		the Font-family string,					("),
//				fsze;		the font size string, including units.	("),
//				fcol;		the font colour,						("),
//				bckgrnd;	the background colour.					("),
//				pwf;		pop width factor, 						("), (see var pw_fact definition above).
//NB Missed parms. must be entered as '' or ""

function get_popup(msg, lne, wd, fnt, fsze, fcol, bckgrnd, pwf)
	{	
	wid=wd;		//Transfer the width to the global variable.
	//Check for a pop width factor.
//alert(pwf); 
	if (pwf!==undefined && pwf!=="")	//A pop width factor has been entered so,
		{
		pw_fact=pwf;	//change the default value.
		}
	//Check the browser and use the required syntax to set values, if entered.
	if(nav)
		{
		if(fnt!==undefined && fnt!=="")	//A font family has been entered, so
			{
			document.pup.style.fontSize=fsze;		//set the 'pup' font size and
			document.pup.style.fontFamily=fnt;		//its family,
			document.ruler.style.fontSize=fsze;		//Ensure that the 'ruler' <span> object
			document.ruler.style.fontFamily=fnt;	//has the same values.			
			}
		else
			{
			document.pup.style.fontSize=d_fs;		//set the 'pup' to the default font size and
			document.pup.style.fontFamily=d_ff;		//the default family,
			document.ruler.style.fontSize=d_fs;		//Ensure that the 'ruler' <span> object
			document.ruler.style.fontFamily=d_ff;	//has the same values.			
			}
		if(fcol!==undefined && fcol!=="")	//A font colour has been entered, so
			{
			document.pup.style.color=fcol;	//set the colour.
			}
		else								//Otherwise,
			{
			document.pup.style.color=d_fc;	//set the default to cancel any previous colour;
			}
		if(bckgrnd!==undefined && bckgrnd!=="")	//A background colour has been entered, so
			{
			document.pup.style.backgroundColor=bckgrnd;	//set the colour.
			}
		else											//Otherwise,
			{
			document.pup.style.backgroundColor=d_bg;	//set the default to cancel any previous
			}											//background.
		}
	if(iex) 
		{
		if(fnt!==undefined && fnt!=="")
			{
			document.getElementById('pup').style.fontSize=fsze;
			document.getElementById('pup').style.fontFamily=fnt;
			document.getElementById('ruler').style.fontSize=fsze;
			document.getElementById('ruler').style.fontFamily=fnt;
			}
		else
			{
			document.getElementById('pup').style.fontSize=d_fs;
			document.getElementById('pup').style.fontFamily=d_ff;
			document.getElementById('ruler').style.fontSize=d_fs;
			document.getElementById('ruler').style.fontFamily=d_ff;
			}
		if(fcol!==undefined && fcol!=="")
			{
			document.getElementById('pup').style.color=fcol;
			}
		else
			{
			document.getElementById('pup').style.color=d_fc;
			}
		if(bckgrnd!==undefined && bckgrnd!=="")
			{
			document.getElementById('pup').style.backgroundColor=bckgrnd;
			}
		else
			{
			document.getElementById('pup').style.backgroundColor=d_bg;
			}
		}	
	if(n_6) 
		{
		if(fnt!==undefined && fnt!=="")
			{
			document.getElementById("pup").style.fontFamily=fnt;
			document.getElementById("ruler").style.fontFamily=fnt;
			}
		else
			{
			document.getElementById("pup").style.fontFamily=d_ff;
			document.getElementById("ruler").style.fontFamily=d_ff;
			}
		if(fsze!==undefined && fsze!=="")
			{
			document.getElementById("pup").style.fontSize=fsze;
			document.getElementById("ruler").style.fontSize=fsze;
			}
		else
			{
			document.getElementById("pup").style.fontSize=d_fs;
			document.getElementById("ruler").style.fontSize=d_fs;
			}
		if(fcol!==undefined && fcol!=="")
			{
			document.getElementById("pup").style.color=fcol;
			}
		else
			{
			document.getElementById("pup").style.color=d_fc;
			}
		if(bckgrnd!==undefined && bckgrnd!=="")
			{
			document.getElementById("pup").style.backgroundColor=bckgrnd;
			}
		else
			{
			document.getElementById("pup").style.backgroundColor=d_bg;
			}
		}
	
	popup(msg, lne)	//Call the original Popup function with the message and single line flag.
	}
	
// assign style object when not already known
function assignSkin() 
	{
	if(nav)
		{
		skin = document.pup;
		}
	if(iex) 
		{
		skin = document.getElementById('pup').style;
		}
	if(n_6) 
		{
		skin = document.getElementById("pup").style;
		}
	}
 
//getting the popwidth - we'll get this only once, too! 
//Then it will always have the stylesheet value
function assignPopWidth()
	{
  	if (iex && !op) 
		{
		popwidth = parseInt(document.getElementById("pup").currentStyle.width);
		}
	if (op) 
		{
		popwidth = parseInt(document.defaultView.getComputedStyle(document.getElementById('pup'),null).width);
		}
	if (n_6) 
		{
		popwidth = parseInt(document.defaultView.getComputedStyle(document.getElementById("pup"),null).getPropertyValue('width'));
		}
	if (wd>0)
		{
		popwidth = parseInt(wd);
		}
	}

// set dynamic coords when the mouse moves
function get_mouse(e)
	{
	var x,y;
	var scroll_x_y = getScrollXY();
  
	//get X
	if (iex) x = scroll_x_y[0] + event.clientX;
	if (nav || n_6) x = e.pageX;

	//get Y
	if (iex) y = scroll_x_y[1] + event.clientY;
	if (nav || n_6) y = e.pageY;
  
	if (popwidth == 0) assignPopWidth();
	if (null === skin) assignSkin();
  
	x += 10; // important: if the popup is where the mouse is, the hoverOver/hoverOut events flicker
  
	var x_y = nudge(x,y); // avoids edge overflow

	if (isNaN(x_y[0])) x_y[0] = 0;
	if (isNaN(x_y[1])) x_y[1] = 0;
  
	//now set coordinates for our popup - n_6 wants "px", the others not
	//remember: the popup is still hidden
	if(nav || iex) 
		{
		skin.left = x_y[0];
		skin.top = x_y[1];
		}
	else if(n_6)
		{
		skin.left = x_y[0] + "px";
		skin.top = x_y[1] + "px";
		}
	}

// avoid edge overflow
function nudge(x,y)
	{
	var dims = getInnerWindowDimensions();
	scroll_x_y = getScrollXY();
  
	// right
	var xtreme = dims[0] - popwidth/pw_fact - minMarginToBorder;	//The value of popwidth is cut down because text with BRK or CR was shifted too far left.
	if (n_6 || nav) xtreme -= 25;	
	if(x > xtreme) 
		{
		x -= (parseInt(popwidth) + minMarginToBorder + 20 ); //20
		}
		// left - should almost never be a problem - we're drawing the window 
		// to the right of the mouse per default (maybe corrected by the code above
		// but then this has the last horizontal word)
	if(x < 1) x -=  x - 1;

	// down - when the mouse is too close to the bottom, move it up.
	// I estimate the lines that fit in the width, assuming (a little pessimisticly) 
	// a char width of 15 pixels and a line height of 20 (That should work for most cases)
	// Unfortunately, I cannot read margin and padding to get even better values, 
	// since JS can only read what is set before itself, apparently. This works quite well 
	// with a padding of 5px.
	est_lines = parseInt(document.getElementById("pup").innerHTML.length / (parseInt(skin.width)/15) );
	est_lines_to_decide = max(est_lines,2);
	if((y + parseInt(est_lines_to_decide * 20)) > (dims[1] + scroll_x_y[1])) 
		{
		y -= parseInt(est_lines * 20) + 20;
		}
  
  return [ x, y ];
	}

//Find the size of the string. The <span> ID = "ruler" must have the same
//font TYPE and SIZE as 'pup'.
function test(s) 
	{
	if (document.getElementById) 
		{
		var rulerSpan = document.getElementById('ruler');
		rulerSpan.innerHTML = s;
		return rulerSpan.offsetWidth;
		}
	}

// write content and display
//Parameters:	msg;	the text for display, (possibly including html tags),
//				lne;	Boolean flag, TRUE = single line display, FALSE= fixed width display,
function popup(msg, lne)
	{
	if (popwidth === 0) assignPopWidth();
	if (null === skin) assignSkin();
	if (null !== skin) { // maybe the browser isn't ready
	if(old) 
		{	//display plain message box for old browsers
		alert(msg);
		return;
		}
 
		if (!isNaN(popwidth)) 
			{ // fallback behaviour (for sthg that has been observed in IE7)
			if(iex || nav)  skin.width = popwidth;
			if(n_6)  skin.width = popwidth + "px";
			} 
		else
			{
			if(iex || nav)  skin.width = 300;
			if(n_6)  skin.width = 300 + "px";
			}
	  
	  //write the message in
	  if(nav) 
		{ 
		skin.document.open();
		skin.document.write(msg);
		skin.document.close();
		}
		document.getElementById("pup").innerHTML = msg;
	  
	  /*If the display flag is TRUE then the width of the Popup is adjusted to match the length of 
	  the text.*/
	if(lne)
		{
		len=test(msg);	//The length of the message string is found and used to
		if(n_6)  skin.width=len+"px";
		//skin.white-space="nowrap"; 
		}
	else	//If the length flag is False
		{
		if(parseInt(wid)!=0)	//Check for a specified width and
			{
			if(iex || nav)  skin.width=wid; 	//re-set the skin width.
			if(n_6)  skin.width=wid+"px";
			}
		}
	  //Make the popup visible
	  skin.visibility ="visible";
	  skin.display = "inline";
	}
}	

//Make content box invisible
function kill()
	{
	if(!old) 
		{
		skin.visibility = "hidden";	//invisible
		skin.display = "none";	//invisible
		}
	}

function getScrollXY() {
  var scrOfX = 0, scrOfY = 0;
  if( typeof( window.pageYOffset ) == 'number' ) {
    //Netscape compliant
    scrOfY = window.pageYOffset;
    scrOfX = window.pageXOffset;
  } else if( document.body && ( document.body.scrollLeft || document.body.scrollTop ) ) {
    //DOM compliant
    scrOfY = document.body.scrollTop;
    scrOfX = document.body.scrollLeft;
  } else if( document.documentElement && ( document.documentElement.scrollLeft || document.documentElement.scrollTop ) ) {
    //IE6 standards compliant mode
    scrOfY = document.documentElement.scrollTop;
    scrOfX = document.documentElement.scrollLeft;
  }
  return [ scrOfX, scrOfY ];
}

function getInnerWindowDimensions(){
	var A;
	if (window.innerHeight !== undefined) A = [window.innerWidth,window.innerHeight]; // most browsers
	else{ // IE varieties
	  var D = (document.documentElement.clientWidth == 0)? document.body: document.documentElement;
	  A = [D.clientWidth,D.clientHeight];
	}
	return A;
}

function max(a,b){
    if (a>b) return a;
    else return b;
}

