Attribute VB_Name = "main"
'Program to create Help Index files from data stored in an Excel Workbook
'Created    24/2/13
'Modified:  16/3/13, 5/11/13, 26/11/13

'v1.1.0     26/11/13
'v1.2.0     10/1/14     System modified to work with new section code based systems.

Option Explicit

Public block() As Integer   'Section storage array.
Public siz() As Integer     'Section size array.
Public num_items As Integer 'Number of items in the index list.
Public n_lines As Integer   'The number of lines in a section.
Public tabint As Integer    'The current Tab position.
Public indnt As Integer     'The basic tabbed indent of a line.

Public lis() As String      '<li> text.
Public uls() As String      '<ul> text.
Public spans() As String    '<span> text.
Public hrefs() As String    '<hrefs> text.
Public topics() As String   'Topic section array.
Public dta1 As String       'RAW DATA sheet.
Public dta2 As String       'SORT DATA sheet.
Public app_path As String   'Application path.
Public tb As String         'Tab character.

Public setup As Boolean
Public canceled As Boolean  'CANCELed flag.

'OBJECTS
Public FSO                  'Basic scripting object.

'WORKBOOK OBJECTS
Public wbk As Object            'Excel Workbook object
Public cur_sht As Object        'Current workbook sheet object.
Public wk_sht As Object         'A worksheet object.
Public rnge As Object           'Worksheet range.


'CLASS OBJECTS
Public xlApp As New ExcelApplication    'ExcelApplication object
Public xlBook As New ExcelWorkbook      'ExcelWorkbook object.
Public cdc As New CDC_class             'Commom Dialog object.

'ShellExecute function for use with Help system.
Private Declare Function ShellExecute Lib "shell32.dll" Alias "ShellExecuteA" _
                                           (ByVal hWnd As Long, _
                                            ByVal lpOperation As String, _
                                            ByVal lpFile As String, _
                                            ByVal lpParameters As String, _
                                            ByVal lpDirectory As String, _
                                            ByVal nShowCmd As Long) As Long

Sub set_up()

    setup = False               'Clear the set-up and
 
    app_path = App.Path & "\"   'Store the application directory.
    
    dta1 = "RAW DATA"           'Define sheet names.
    dta2 = "SORT DATA"
   
    tb = vbTab
    indnt = 6
    
    'Define the HTML tag data.
    ReDim lis(2)
    lis(0) = "<li>"
    lis(1) = "<li class=" + Chr(34) + "lastChild" + Chr(34) + ">"
    lis(2) = "</li>"
    ReDim uls(1)
    uls(0) = "<ul>"
    uls(1) = "</ul>"
    ReDim spans(1)
    spans(0) = "<span style=" + Chr(34) + "font-size:110%;font-weight:bold" + Chr(34) + ">"
    spans(1) = "</span>"
    ReDim hrefs(2)
    'hrefs(0) = "<a href=" + Chr(34) + "javascript:void(0);" + Chr(34) + " onclick=" + Chr(34) + "parent.loadhtmla('"
    hrefs(0) = "<a href=" + Chr(34) + "javascript:void(0);" + Chr(34) + " onclick=" + Chr(34) + "parent.display('"
    hrefs(1) = "')" + Chr(34) + " >"
    hrefs(2) = "</a>"
    
    ReDim topics(6, 1)  'Re-dimension the Topics and Sections arrays.
    ReDim block(0, 6)
    
    canceled = False
   
    open_wb             'Open a workbook

    If Not canceled Then
        setup = True        'Set the set-up flag.
    Else
        close_down
    End If

End Sub

'Routine to open a workbook and set up data.
'Procedure name:    open_wb

Sub open_wb()
    
    Dim j, p_d As Integer
    Dim b_nme, full_file_path As String
    Dim st_fact As Single
    
    full_file_path = choose_file    'Select the data file.
 
    If Not canceled Then
        Set xlBook = xlApp.Add(full_file_path)  'Open the book.
        Set wbk = xlBook.get_book   'Store the workbook object
    End If
    
End Sub

'Routine to select and get the name of a data file.
'Function name: choose_file()

 Function choose_file()
 
    Dim flgg As Long
    Dim fltr, ttl, f_n As String

    fltr = "Excel  files(*.XLS)" & Chr$(0) & "*.XLS"    'ANY Excel file can be opened.
    flgg = cdlOFNNoChangeDir Or cdlOFNPathMustExist     'Set up the flags
    ttl = "Index maker: SELECT AN EXCEL DATA FILE"
 
    f_n = cdc.ShowOpen(im_main.hWnd, fltr, flgg, ttl, app_path)

    choose_file = f_n
    
End Function

'Routine to run an html file in an IE browser.
'Procedure name:    run_help(f_txt, f_nme)
'Parameter:         f_txt;  the Help file, full-path name,
'                   f_nme;  the secondary file name to be loaded in the
'                           left-hand section.

Sub run_help(f_txt, f_nme)

    If f_nme <> "" Then
        setup_htm f_nme 'Write the secondary file name to the Help folder.
    End If
 
    On Error GoTo errer
    
    'ShellExecute im_main.hWnd, "open", "C:\Program Files\Internet Explorer\iexplore.exe", f_txt, vbNullString, 1
     ShellExecute im_main.hWnd, "open", f_txt, vbNullString, vbNullString, 1
Exit Sub

errer:
    MsgBox "Error #" & Str(Err.Number) & " was generated by " _
                   & vbCrLf & Err.Source & vbCrLf & Err.Description, _
                   0, 16, "IE ERROR"
                              
    Err.Clear       'Clear the error object.

End Sub

'Routine to write the secondary HTML file name into the Help folder.
'The name of the file is fixed as "source.htm" and it is a copy of the selected
'Help file, (Contents, Index or Search).
'Procedure name:    setup_htm(fn)
'Parameter:         fn;    the file name.

Sub setup_htm(fn)

    Dim FSO, file1 As Object
    Dim s_path As String
    
    Set FSO = CreateObject("Scripting.FileSystemObject")    'Define the File System Object
    
    s_path = app_path + "Help\source.htm"   'Store the 'Source' file path name.
    
    If Dir(s_path) <> "" Then   'If 'source.htm' exists, delete it.
        Kill s_path
    End If
    
    Set file1 = FSO.GetFile(fn) 'Get the requested file, (Contents, Index or Search), and
    file1.Copy (app_path + "Help\source.htm")   'rename it as 'source.htm'.
    
    Set FSO = Nothing   'Clear the File System objects.
    Set file1 = Nothing

End Sub

'Routine to close down the system.
'Procedure name:    close_down

Sub close_down()
    
    Dim fc As Integer
    
    Set cdc = Nothing   'Release the CDC class handle.
    
    'RELEASE THE EXCEL CLASS OBJECTS
    Set rnge = Nothing      'Release the handles in increasing order of complexity. i.e.  Range of cells,
    Set cur_sht = Nothing   'Sheet,
    Set wbk = Nothing       'Workbook,
    Set xlBook = Nothing    'ExcelWorkbook then
    Set xlApp = Nothing     'ExcelApplication.
    
    'UNLOAD ALL FORMS TO CLOSE THE PACKAGE.
    fc = -1
    Do Until fc = 0 'It has to be done this way because, as forms are unloaded, the remaining indices change.
        fc = Forms.Count - 1    'Unload all Loaded forms.
        Unload Forms(fc)
    Loop
    
End Sub
